@@ -24,12 +24,14 @@ from typing import List, Optional, Dict
 from .base import EnvironmentBase, AsyncWrapper
 from ..models import (
     InstanceRequest,
-    InstanceRecord,
+    InstanceResponse,
     Environment as EnvironmentModel,
     VerifiersCheckResponse,
-    VerificationResponse,
     VerifiersExecuteResponse,
+    TaskListResponse,
+    AccountResponse,
 )
+from .tasks import Task
 
 from .instance import (
     AsyncInstanceClient,
@@ -102,14 +104,14 @@ class AsyncEnv(EnvironmentBase):
     async def resources(self) -> List[Resource]:
         return await self.instance.resources()
 
-    async def close(self) -> InstanceRecord:
+    async def close(self) -> InstanceResponse:
         return await _delete_instance(self._load_client, self.instance_id)
 
     async def verify(self, validator: ValidatorType) -> ExecuteFunctionResponse:
         return await self.instance.verify(validator)
 
     async def verify_raw(
-        self, function_code: str, function_name: str
+        self, function_code: str, function_name: str | None = None
     ) -> ExecuteFunctionResponse:
         return await self.instance.verify_raw(function_code, function_name)
 
@@ -152,12 +154,14 @@ class AsyncEnv(EnvironmentBase):
 class AsyncFleet:
     def __init__(
         self,
-        api_key: Optional[str] = os.getenv("FLEET_API_KEY"),
+        api_key: Optional[str] = None,
         base_url: Optional[str] = None,
         httpx_client: Optional[httpx.AsyncClient] = None,
         max_retries: int = DEFAULT_MAX_RETRIES,
         timeout: float = DEFAULT_TIMEOUT,
     ):
+        if api_key is None:
+            api_key = os.getenv("FLEET_API_KEY")
         self._httpx_client = httpx_client or default_httpx_client(max_retries, timeout)
         self.client = AsyncWrapper(
             api_key=api_key,
@@ -182,13 +186,13 @@ class AsyncFleet:
     ) -> AsyncEnv:
         if ":" in env_key:
             env_key_part, version = env_key.split(":", 1)
-            if not version.startswith("v"):
+            if not version.startswith("v") and len(version) != 0 and version[0].isdigit():
                 version = f"v{version}"
         else:
             env_key_part = env_key
             version = None
 
-        request = InstanceRequest(env_key=env_key_part, version=version, region=region)
+        request = InstanceRequest(env_key=env_key_part, version=version, region=region, created_from="sdk")
         region_base_url = REGION_BASE_URL.get(region)
         response = await self.client.request(
             "POST",
@@ -231,14 +235,54 @@ class AsyncFleet:
             self.client, bundle_data, args, kwargs, timeout
         )
 
-    async def delete(self, instance_id: str) -> InstanceRecord:
+    async def delete(self, instance_id: str) -> InstanceResponse:
         return await _delete_instance(self.client, instance_id)
 
+    async def load_tasks(self, env_key: Optional[str] = None) -> List[Task]:
+        """Load tasks for the authenticated team, optionally filtered by environment.
+        
+        Args:
+            env_key: Optional environment key to filter tasks by
+            
+        Returns:
+            List[Task] containing Task objects
+        """
+        params = {}
+        if env_key is not None:
+            params["env_key"] = env_key
+            
+        response = await self.client.request("GET", "/v1/tasks", params=params)
+        task_list_response = TaskListResponse(**response.json())
+        
+        # Transform TaskResponse objects to Task objects
+        tasks = []
+        for task_response in task_list_response.tasks:
+            task = Task(
+                key=task_response.key,
+                prompt=task_response.prompt,
+                env_id=task_response.environment_id,  # Map environment_id -> env_id
+                created_at=task_response.created_at,
+                verifier=None,  # Keep blank for now as requested
+                metadata={}  # Default empty metadata
+            )
+            tasks.append(task)
+        
+        return tasks
+
+    async def account(self) -> AccountResponse:
+        """Get account information including instance limits and usage.
+        
+        Returns:
+            AccountResponse containing team_id, team_name, instance_limit, and instance_count
+        """
+        response = await self.client.request("GET", "/v1/account")
+        return AccountResponse(**response.json())
+
 
 # Shared
-async def _delete_instance(client: AsyncWrapper, instance_id: str) -> InstanceRecord:
+async def _delete_instance(client: AsyncWrapper, instance_id: str) -> InstanceResponse:
     response = await client.request("DELETE", f"/v1/env/instances/{instance_id}")
-    return InstanceRecord(**response.json())
+    return InstanceResponse(**response.json())
 
 
 async def _check_bundle_exists(
@@ -258,7 +302,7 @@ async def _execute_verifier_remote(
     kwargs: dict,
     timeout: Optional[int] = 30,
     needs_upload: bool = True,
-) -> VerificationResponse:
+) -> VerifiersExecuteResponse:
     # Pickle args and kwargs together
     # The first arg should be None as a placeholder for env
     args_with_none = (None,) + args
